@@ -35,12 +35,14 @@
 
 #pragma once
 
+#include "fabric_graph_data.h"
 #include "file_parser_fabric_abs.h"
 
 class FileParserVirtualization : public FileParserFabricAbs
 {
     SectionParser<VportRecord> vport_section_parser;
     SectionParser<VnodeRecord> vnode_section_parser;
+    SectionParser<VportPkeyRecord> pkeys_section_parser;
 
    public:
     FileParserVirtualization(const string& file_name,
